# eric7.Snapshot.SnapshotDefaultGrabber

Module implementing a grabber object for non-Wayland desktops.

### Global Attributes

None

### Classes

SnapshotDefaultGrabber | Class implementing a grabber object for non-Wayland desktops.

### Functions

None

## SnapshotDefaultGrabber

Class implementing a grabber object for non-Wayland desktops.

### Signals

grabbed(QPixmap)
  emitted after the grab operation is finished

### Derived from

QObject

### Class Attributes

None

### Class Methods

None

### Methods

SnapshotDefaultGrabber | Constructor
__captured | Private slot to show a preview of the snapshot.
__grabEllipse | Private method to grab an elliptical screen region.
__grabFreehand | Private method to grab a non-rectangular screen region.
__grabRectangle | Private method to grab a rectangular screen region.
__grabTimerTimeout | Private slot to perform a delayed grab operation.
__performGrab | Private method to perform a screen grab other than a selected region.
__startUndelayedGrab | Private slot to perform an undelayed grab operation.
eventFilter | Public method to handle event for other objects.
grab | Public method to perform a grab operation potentially after a delay.
supportedModes | Public method to get the supported screenshot modes.

### Static Methods

None

#### SnapshotDefaultGrabber (Constructor)

SnapshotDefaultGrabber(parent=None)

Constructor

parent (QObject)
  reference to the parent object

#### SnapshotDefaultGrabber.__captured

__captured(pixmap)

Private slot to show a preview of the snapshot.

pixmap (QPixmap)
  pixmap of the snapshot

#### SnapshotDefaultGrabber.__grabEllipse

__grabEllipse()

Private method to grab an elliptical screen region.

#### SnapshotDefaultGrabber.__grabFreehand

__grabFreehand()

Private method to grab a non-rectangular screen region.

#### SnapshotDefaultGrabber.__grabRectangle

__grabRectangle()

Private method to grab a rectangular screen region.

#### SnapshotDefaultGrabber.__grabTimerTimeout

__grabTimerTimeout()

Private slot to perform a delayed grab operation.

#### SnapshotDefaultGrabber.__performGrab

__performGrab(mode)

Private method to perform a screen grab other than a selected region.

mode (SnapshotModes)
  screenshot mode

#### SnapshotDefaultGrabber.__startUndelayedGrab

__startUndelayedGrab()

Private slot to perform an undelayed grab operation.

#### SnapshotDefaultGrabber.eventFilter

eventFilter(obj, evt)

Public method to handle event for other objects.

obj (QObject)
  reference to the object
evt (QEvent)
  reference to the event

Return:
  flag indicating that the event should be filtered out

Return Type:
  bool

#### SnapshotDefaultGrabber.grab

grab(mode, delay, _captureCursor, _captureDecorations)

Public method to perform a grab operation potentially after a delay.

mode (ScreenshotModes)
  screenshot mode
delay (int)
  delay in seconds
_captureCursor (bool)
  flag indicating to include the mouse cursor (unused)
_captureDecorations (bool)
  flag indicating to include the window decorations (unused)

#### SnapshotDefaultGrabber.supportedModes

supportedModes()

Public method to get the supported screenshot modes.

Return:
  tuple of supported screenshot modes

Return Type:
  tuple of SnapshotModes

Up